@@ -14,7 +14,7 @@ fn empty() {
 fn order() {
     // Shuffle integers from 1 to 1000, and order them so that divisors
     // are located before the numbers they divide.
-    let mut rng = rngs::OsRng::new().unwrap();
+    let mut rng = rngs::OsRng;
     let mut ints = (1..1000).collect_vec();
     ints.shuffle(&mut rng);
     let sorted = tsort(&ints, |&n| {
@@ -37,7 +37,7 @@ fn order() {
 fn complexity() {
     // To ensure that the sort is O(|E| + |V|), we ensure that the
     // successors for a particular node are requested exactly one time.
-    let mut rng = rngs::OsRng::new().unwrap();
+    let mut rng = rngs::OsRng;
     let mut ints = (1..1000).collect_vec();
     ints.shuffle(&mut rng);
     let mut requested = 0;
@@ -57,7 +57,7 @@ fn complexity() {
 // topological_sort_into_groups makes no guarantees about node order within
 // each group).
 fn tsig(succs: &[&[usize]]) -> Result<Vec<Vec<usize>>, (Vec<Vec<usize>>, Vec<usize>)> {
-    let nodes: Vec<usize> = (0..succs.len()).into_iter().collect();
+    let nodes: Vec<usize> = (0..succs.len()).collect();
     match topological_sort_into_groups(&nodes, |&n| succs[n].iter().cloned()) {
         Ok(mut groups) => {
             for group in groups.iter_mut() {
